@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the positive/negative sentiment of text
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Moo;
 use strictures 2;
@@ -11,6 +11,7 @@ use namespace::clean;
 
 use Lingua::EN::Opinion::Positive;
 use Lingua::EN::Opinion::Negative;
+use Lingua::EN::Opinion::Emotion;
 
 use File::Slurper qw( read_text );
 use Lingua::EN::Sentence qw( get_sentences );
@@ -40,6 +41,12 @@ has scores => (
 );
 
 
+has nrc_scores => (
+    is       => 'rw',
+    init_arg => undef,
+);
+
+
 sub analyze {
     my ($self) = @_;
 
@@ -89,6 +96,36 @@ sub averaged_score {
     return \@averaged;
 }
 
+
+sub nrc_sentiment {
+    my ($self) = @_;
+
+    my $null_state = { anger=>0, anticipation=>0, disgust=>0, fear=>0, joy=>0, negative=>0, positive=>0, sadness=>0, surprise=>0, trust=>0 };
+
+    my $contents = $self->file ? read_text( $self->file ) : $self->text;
+
+    $self->sentences( get_sentences($contents) );
+
+    my @sentences = map { $_ } @{ $self->sentences };
+
+    my @scores;
+
+    my $emotion = Lingua::EN::Opinion::Emotion->new();
+
+    for my $sentence ( @sentences ) {
+        $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
+
+        my @words = split /\s+/, $sentence;
+
+        for my $word ( @words ) {
+            push @scores, exists $emotion->wordlist->{$word}
+                ? $emotion->wordlist->{$word} : $null_state;
+        }
+    }
+
+    $self->nrc_scores( \@scores );
+}
+
 1;
 
 __END__
@@ -103,21 +140,25 @@ Lingua::EN::Opinion - Measure the positive/negative sentiment of text
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
   use Lingua::EN::Opinion;
   my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt' );
   $opinion->analyze();
-  my $sentences = $opinion->sentences;
-  my $scores = $opinion->scores;
-  my $averaged = $opinion->averaged_score(5);
+  my $score = $opinion->averaged_score(5);
+  # OR
+  $opinion = Lingua::EN::Opinion->new( text => 'Mary had a little lamb...' );
+  $opinion->nrc_sentiment();
+  # And now do something cool with $opinion->nrc_scores...
 
 =head1 DESCRIPTION
 
 A C<Lingua::EN::Opinion> measures the positive/negative sentiment of text.
 
+NOTE: This module is 3.4MB because of the GIANT sentiment text it comes with.
+
 Please see the F<eg/> and F<t/> scripts for example usage.
 
 =head1 ATTRIBUTES
@@ -138,6 +179,10 @@ Computed result.
 
 Computed result.
 
+=head2 nrc_scores
+
+Computed result.
+
 =head1 METHODS
 
 =head2 new()
@@ -148,9 +193,10 @@ Create a new C<Lingua::EN::Opinion> object.
 
 =head2 analyze()
 
-  $score = $opinion->analyze();
+  $opinion->analyze();
 
-Measure the positive/negative sentiment of text.
+Measure the positive/negative sentiment of text.  This method sets the B<scores>
+and B<sentences> attributes.
 
 =head2 averaged_score()
 
@@ -165,6 +211,23 @@ For example, if there are 400 sentences, B<bins> of 10 will result in 40 data
 points.  Each point will be the mean of each successive bin-sized set of points
 in the analyzed score.
 
+=head2 nrc_sentiment()
+
+Compute the NRC sentiment of the given text.
+
+This is given by a 0/1 list of these 10 emotional elements:
+
+  anger
+  anticipation
+  disgust
+  fear
+  joy
+  negative
+  positive
+  sadness
+  surprise
+  trust
+
 =head1 SEE ALSO
 
 L<Moo>
@@ -177,6 +240,8 @@ L<Statistics::Lite>
 
 L<https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html#lexicon>
 
+L<http://saifmohammad.com/WebPages/NRC-Emotion-Lexicon.htm>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
